.. include:: ../../README.md
   :parser: myst_parser.sphinx_
   :start-after: </p>
   :end-before: ---

.. toctree::
   :caption: Sections
   :maxdepth: 3
   :hidden:

   state_machines/index
   api
   schema
   developer_guide
   changelog

.. toctree::
   :caption: Links
   :hidden:

   bpod-core on GitHub <https://github.com/int-brain-lab/bpod-core>
   bpod-core on PyPI <https://pypi.org/project/bpod-core/>
